export class ImSocket {
  /**
   * @param {string} url - WebSocket 服务器地址
   * @param {number} checkInterval - 检查连接状态的时间间隔，单位毫秒
   */
  constructor(url, checkInterval = 5000) {
    this.url = url;
    this.checkInterval = checkInterval;
    this.ws = null;
    this.onMessageCallback = null;
    this.isConnecting = false;
    this.connect();
    this.startHeartbeat();
  }

  connect() {
    if (this.ws && (this.ws.readyState === WebSocket.OPEN || this.ws.readyState === WebSocket.CONNECTING)) {
      return;
    }

    if (this.isConnecting) {
      return;
    }

    this.isConnecting = true;

    this.ws = new WebSocket(this.url);

    this.ws.onmessage = (event) => {
      // 根据需要处理消息
      if (this.onMessageCallback) this.onMessageCallback(event.data);
    };

    this.ws.onclose = (event) => {
      this.isConnecting = false;
    };
  }

  // 定时检查连接状态
  startHeartbeat() {
    if (this.heartbeatTimer) return;

    this.heartbeatTimer = setInterval(() => {
      if (!this.ws || this.ws.readyState !== WebSocket.OPEN) {
        this.connect();
      }
    }, this.checkInterval);
  }

   // 清除重连定时器的方法
  stopHeartbeat() {
    if (this.heartbeatTimer) {
      clearInterval(this.heartbeatTimer);
      this.heartbeatTimer = null;
    }
  }

  // 主动关闭 WebSocket 连接，并清除定时任务
  close() {
    this.stopHeartbeat();
    this.ws?.close();
    this.ws = null;
  }
  onMessage(callback) {
    this.onMessageCallback = callback;
  }
}
